@@ -14,13 +14,12 @@ from django.utils.translation import ugettext_lazy as _
 
 
 class WechatForm(forms.Form):
-    urls = forms.CharField(
+   urls = forms.CharField(
         label=_('Wechat robot url'),
         widget=forms.Textarea(attrs={
             'class': 'span6', 'placeholder': 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=xxx-xxx-xxx-xxx-xxx'}),
         help_text=_('Enter wechat robot url.'))
 
-
 class WechatPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to WeChat.
@@ -45,7 +44,7 @@ class WechatPlugin(NotificationPlugin):
         if not url:
             return ''
         return url
-
+        
     def is_configured(self, project):
         """
         Check if plugin is configured.
@@ -66,24 +65,37 @@ class WechatPlugin(NotificationPlugin):
             return
 
         send_url = self.get_webhook_urls(group.project)
-        title = '【{}】发生错误，请尽快查看处理!' .format(event.project.slug)
-        url = "{}events/{}/".format(group.get_absolute_url(), event.event_id),
+        title = "【{}】发生错误，请尽快查看处理!".format(event.project.slug)
+        url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
 
         data = {
-            "msgtype": "news",
-            "news": {
-                "articles": [
-                    {
-                        "title": title,
-                        "description": event.title or event.message,
-                        "url": url,
-                        "picurl": "http://pic1.zhimg.com/v2-c41cd2b3b6c58245908ad89f7ddc55e7_b.jpg"
-                    }
-                ]
-            }
+          "msgtype": "news",
+    "news": {
+       "articles" : [
+           {
+               "title" : title,
+               "description" : event.title or event.message,
+               "url" : url,
+               "picurl" : "http://pic1.zhimg.com/v2-c41cd2b3b6c58245908ad89f7ddc55e7_b.jpg"
+           }
+        ]
+    }
         }
         requests.post(
             url=send_url,
             headers={"Content-Type": "application/json"},
             data=json.dumps(data)
         )
+#       data = {
+#             "msgtype": "markdown",
+#             "markdown": {
+#                 "content": '''
+#                 ## 错误报警   \n
+#                 ### 项目{project_name}发生错误，请尽快查看处理!   \n   ![screenshot](http://pic1.zhimg.com/v2-c41cd2b3b6c58245908ad89f7ddc55e7_b.jpg)
+# > [点我直接查看BUG]({link})
+#                 '''.format(
+#                     project_name=project,
+#                     link=link,
+#                 ),
+#             },
+#             }
